@@ -26,6 +26,7 @@
 import datetime
 import feedparser
 from httplib2 import Http
+import ebdata.retrieval.log  # sets up base handlers.
 import logging
 
 from django.contrib.gis.geos import Point
@@ -40,7 +41,7 @@ from ebpub.utils.geodjango import intersects_metro_bbox
 # unescape html before putting it in the db.
 from ebdata.retrieval.utils import convert_entities
 
-logger = logging.getLogger()
+logger = logging.getLogger('eb.retrieval.georss')
 
 
 class LocalNewsScraper(object):
@@ -92,7 +93,9 @@ class LocalNewsScraper(object):
                 item.schema = schema
                 item.description = description
                 item.url = item_url
-                item.location_name = entry.get('x-calconnect-street') or entry.get('georss_featurename')
+                # Support both georss and xcal for getting the location name.
+                # TODO: should also support ev:location per http://web.resource.org/rss/1.0/modules/event/
+                item.location_name = entry.get('xCal_x-calconnect-street') or entry.get('x-calconnect-street') or entry.get('georss_featurename') or entry.get('featurename')
                 item.item_date = datetime.datetime(*entry.updated_parsed[:6])
                 item.pub_date = datetime.datetime(*entry.updated_parsed[:6])
                 _short_title = item.title[:30] + '...'
@@ -153,8 +156,8 @@ class LocalNewsScraper(object):
                         item.location_name = block.pretty_name
                         item.block = block
                     except reverse.ReverseGeocodeError:
-                        logger.debug(" Failed to reverse geocode %s for %r" % (item.location.wkt, _short_title))
-                        item.location_name = u''
+                        logger.info(" Skip, failed to reverse geocode %s for %r" % (item.location.wkt, _short_title))
+                        continue
                 item.save()
                 if status == 'added':
                     addcount += 1
@@ -184,17 +187,19 @@ def main(argv=None):
         action='store'
         )
 
+    from ebpub.utils.script_utils import add_verbosity_options, setup_logging_from_opts
+    add_verbosity_options(parser)
+
     options, args = parser.parse_args(argv)
-    
+    setup_logging_from_opts(options, logger)
+
     if len(args) < 1:
         parser.print_usage()
         sys.exit(0)
-    
+
     scraper = LocalNewsScraper(url=args[0],  schema_slug=options.schema, http_cache=options.http_cache)
 
     scraper.update()
 
-    
-
 if __name__ == '__main__':
     main()
